summaryrefslogtreecommitdiffstats
path: root/kio
diff options
context:
space:
mode:
authorDarrell Anderson <humanreadable@yahoo.com>2012-06-08 15:51:46 -0500
committerDarrell Anderson <humanreadable@yahoo.com>2012-06-08 15:51:46 -0500
commit6ed1ea98db6b1b369e7561efcc2c666b810e5446 (patch)
tree69da6d265387965c04a9584547ec42d4d372717d /kio
parent09d01cacf80d21ad213e6520b35e7f06e9546a83 (diff)
downloadtdelibs-6ed1ea98db6b1b369e7561efcc2c666b810e5446.tar.gz
tdelibs-6ed1ea98db6b1b369e7561efcc2c666b810e5446.zip
Update XDG information in support of bug report 892.
Diffstat (limited to 'kio')
-rw-r--r--kio/DESIGN.mimetypes14
-rw-r--r--kio/application.desktop16
-rw-r--r--kio/kcmodule.desktop16
-rw-r--r--kio/kcomprfilter.desktop2
-rw-r--r--kio/kdatatool.desktop2
-rw-r--r--kio/kfile/kfiledialog.cpp6
-rw-r--r--kio/kfile/kfilemetapreview.cpp4
-rw-r--r--kio/kfile/kopenwith.cpp2
-rw-r--r--kio/kfile/kpropertiesdialog.cpp30
-rw-r--r--kio/kfile/kpropertiesdialog.h2
-rw-r--r--kio/kfile/kpropsdlgplugin.desktop4
-rw-r--r--kio/kfile/krecentdocument.cpp4
-rw-r--r--kio/kfileplugin.desktop2
-rw-r--r--kio/kio/job.cpp2
-rw-r--r--kio/kio/kfilemetainfo.cpp4
-rw-r--r--kio/kio/kfilemetainfo.h4
-rw-r--r--kio/kio/kmimetype.cpp28
-rw-r--r--kio/kio/kmimetype.h4
-rw-r--r--kio/kio/krun.cpp10
-rw-r--r--kio/kio/krun.h4
-rw-r--r--kio/kio/kservice.cpp20
-rw-r--r--kio/kio/kservicefactory.h2
-rw-r--r--kio/kio/kservicegroup.cpp4
-rw-r--r--kio/kio/kservicegroup.h4
-rw-r--r--kio/kio/kservicetype.cpp10
-rw-r--r--kio/kio/ktrader.h10
-rw-r--r--kio/kio/previewjob.cpp4
-rw-r--r--kio/kio/thumbcreator.h2
-rw-r--r--kio/kpasswdserver.desktop10
-rw-r--r--kio/kscan.desktop2
-rw-r--r--kio/kurifilterplugin.desktop2
-rw-r--r--kio/misc/kio_uiserver.desktop2
-rw-r--r--kio/misc/kpac/proxyscout.desktop10
-rw-r--r--kio/misc/kssld/kssld.desktop10
-rw-r--r--kio/misc/kwalletd/kwalletd.desktop10
-rw-r--r--kio/renamedlgplugin.desktop2
-rw-r--r--kio/tests/dummymeta.desktop2
-rw-r--r--kio/tests/kruntest.cpp2
38 files changed, 134 insertions, 134 deletions
diff --git a/kio/DESIGN.mimetypes b/kio/DESIGN.mimetypes
index ffec64f44..7f1d81b11 100644
--- a/kio/DESIGN.mimetypes
+++ b/kio/DESIGN.mimetypes
@@ -1,9 +1,9 @@
TODO: servicetypes
TODO: mimetypes
-Service type inheritance (X-KDE-Derived)
+Service type inheritance (X-TDE-Derived)
========================================
-X-KDE-Derived is for service types. ST1 derives from ST2 means ST1 is more specific than ST2.
+X-TDE-Derived is for service types. ST1 derives from ST2 means ST1 is more specific than ST2.
If a service implements ST1, it also implements ST2, but not the other way round.
For instance, KoDocument derives from KParts/ReadWritePart, which derives from KParts/ReadOnlyPart,
@@ -16,19 +16,19 @@ We need a mechanism to also say that "text/xml is a special case of text/plain",
or "text/docbook is a kind of text/sgml", or "application/x-smb-workgroup is a kind
of inode/directory", etc. See below.
-Why mimetype "inheritance" doesn't use X-KDE-Derived
+Why mimetype "inheritance" doesn't use X-TDE-Derived
====================================================
The confusing thing is that we said "a mimetype is a servicetype". But that's not exactly correct.
As Waldo noted, "the ability to open a mimetype" is what's a servicetype.
-So if text/xml said X-KDE-Derived=text/plain (i.e. ST1=text/xml, ST2=text/plain),
+So if text/xml said X-TDE-Derived=text/plain (i.e. ST1=text/xml, ST2=text/plain),
then an application opening text/xml (ST1) could also open text/plain (ST2) - which is not necessarily true.
We want the other way round: to be able to open special kinds of text/plain in a plain text editor.
-This is what X-KDE-IsAlso was introduced for. X-KDE-IsAlso kind of "works the other way" than X-KDE-Derived.
+This is what X-TDE-IsAlso was introduced for. X-TDE-IsAlso kind of "works the other way" than X-TDE-Derived.
If M1 is a special kind of M2 (mimetypes), then "the ability to open M2" derives from "the ability to open M1"
-So we say in text/xml: X-KDE-IsAlso=text/plain, and applications that can open text/plain can also open text/xml.
+So we say in text/xml: X-TDE-IsAlso=text/plain, and applications that can open text/plain can also open text/xml.
Pattern Accuracy
======================
In some cases of inheritance several mimetypes shares the same extension (with the primary case being Ogg Multimedia files).
-This has been solved sofar by matching the extension to most generic mimetype. To indicate that the mimetype can be refined further, the flag X-KDE-PatternsAccuracy can be set. The value to X-KDE-PatternsAccuracy is a number between 0-100, with 100 being the default if not set. Any values below 100 is interpreted as the possibility of further mimetype refinement.
+This has been solved sofar by matching the extension to most generic mimetype. To indicate that the mimetype can be refined further, the flag X-TDE-PatternsAccuracy can be set. The value to X-TDE-PatternsAccuracy is a number between 0-100, with 100 being the default if not set. Any values below 100 is interpreted as the possibility of further mimetype refinement.
diff --git a/kio/application.desktop b/kio/application.desktop
index 27c30c967..d9e9fc3c2 100644
--- a/kio/application.desktop
+++ b/kio/application.desktop
@@ -1,6 +1,6 @@
[Desktop Entry]
Type=ServiceType
-X-KDE-ServiceType=Application
+X-TDE-ServiceType=Application
Name=Application
Name[af]=Program
Name[ar]=تطبيق
@@ -92,10 +92,10 @@ Type=bool
[PropertyDef::DocPath]
Type=TQString
-[PropertyDef::X-KDE-SubstituteUID]
+[PropertyDef::X-TDE-SubstituteUID]
Type=bool
-[PropertyDef::X-KDE-Username]
+[PropertyDef::X-TDE-Username]
Type=TQString
[PropertyDef::StartupWMClass]
@@ -104,21 +104,21 @@ Type=TQString
[PropertyDef::StartupNotify]
Type=bool
-[PropertyDef::X-KDE-WMClass]
+[PropertyDef::X-TDE-WMClass]
Type=TQString
-[PropertyDef::X-KDE-StartupNotify]
+[PropertyDef::X-TDE-StartupNotify]
Type=bool
[PropertyDef::X-DCOP-ServiceName]
Type=TQString
-[PropertyDef::X-KDE-ParentApp]
+[PropertyDef::X-TDE-ParentApp]
Type=TQString
-[PropertyDef::X-KDE-HasTempFileOption]
+[PropertyDef::X-TDE-HasTempFileOption]
Type=bool
-[PropertyDef::X-KDE-Protocols]
+[PropertyDef::X-TDE-Protocols]
Type=TQStringList
diff --git a/kio/kcmodule.desktop b/kio/kcmodule.desktop
index e70b87850..c3ab78532 100644
--- a/kio/kcmodule.desktop
+++ b/kio/kcmodule.desktop
@@ -1,6 +1,6 @@
[Desktop Entry]
Type=ServiceType
-X-KDE-ServiceType=KCModule
+X-TDE-ServiceType=KCModule
Name=TDE Control Module
Name[af]=TDE Beheer Module
Name[ar]=وحدة تحكم كيدي
@@ -84,26 +84,26 @@ Name[zh_HK]=TDE 控制模組
Name[zh_TW]=TDE 控制模組
Name[zu]=Ingxenye ye-TDE Control
-[PropertyDef::X-KDE-FactoryName]
+[PropertyDef::X-TDE-FactoryName]
Type=TQString
-[PropertyDef::X-KDE-RootOnly]
+[PropertyDef::X-TDE-RootOnly]
Type=bool
# a list of all components this KCM belongs to
-[PropertyDef::X-KDE-ParentComponents]
+[PropertyDef::X-TDE-ParentComponents]
Type=TQStringList
# the id of the parent in the TreeList
-[PropertyDef::X-KDE-CfgDlgHierarchy]
+[PropertyDef::X-TDE-CfgDlgHierarchy]
Type=TQString
# sets the order of the modules in the TreeList/IconList
-[PropertyDef::X-KDE-Weight]
+[PropertyDef::X-TDE-Weight]
Type=int
-[PropertyDef::X-KDE-RootOnly]
+[PropertyDef::X-TDE-RootOnly]
Type=bool
-[PropertyDef::X-KDE-IsHiddenByDefault]
+[PropertyDef::X-TDE-IsHiddenByDefault]
Type=bool
diff --git a/kio/kcomprfilter.desktop b/kio/kcomprfilter.desktop
index be9bdc2c1..87be942f4 100644
--- a/kio/kcomprfilter.desktop
+++ b/kio/kcomprfilter.desktop
@@ -1,6 +1,6 @@
[Desktop Entry]
Type=ServiceType
-X-KDE-ServiceType=KDECompressionFilter
+X-TDE-ServiceType=KDECompressionFilter
Name=TDE Compression Filter
Name[af]=TDE Kompakteer Filter
Name[az]=TDE Sıxışdırma Filtri
diff --git a/kio/kdatatool.desktop b/kio/kdatatool.desktop
index 5424573c6..a58357d41 100644
--- a/kio/kdatatool.desktop
+++ b/kio/kdatatool.desktop
@@ -1,6 +1,6 @@
[Desktop Entry]
Type=ServiceType
-X-KDE-ServiceType=KDataTool
+X-TDE-ServiceType=KDataTool
Comment=TDE Data Tool
Comment[af]=TDE Data Program
Comment[ar]=أداة كيدي للبيانات
diff --git a/kio/kfile/kfiledialog.cpp b/kio/kfile/kfiledialog.cpp
index f84db825b..f9086cff7 100644
--- a/kio/kfile/kfiledialog.cpp
+++ b/kio/kfile/kfiledialog.cpp
@@ -1948,8 +1948,8 @@ void KFileDialog::updateAutoSelectExtension (void)
{
KMimeType::Ptr mime = KMimeType::mimeType (filter);
- // first try X-KDE-NativeExtension
- TQString nativeExtension = mime->property ("X-KDE-NativeExtension").toString ();
+ // first try X-TDE-NativeExtension
+ TQString nativeExtension = mime->property ("X-TDE-NativeExtension").toString ();
if (nativeExtension.at (0) == '.')
{
d->extension = nativeExtension.lower ();
@@ -1957,7 +1957,7 @@ void KFileDialog::updateAutoSelectExtension (void)
<< d->extension << "\'" << endl;
}
- // no X-KDE-NativeExtension
+ // no X-TDE-NativeExtension
if (d->extension.isEmpty ())
{
d->extension = getExtensionFromPatternList (mime->patterns ()).lower ();
diff --git a/kio/kfile/kfilemetapreview.cpp b/kio/kfile/kfilemetapreview.cpp
index d5a2d4019..155e1194c 100644
--- a/kio/kfile/kfilemetapreview.cpp
+++ b/kio/kfile/kfilemetapreview.cpp
@@ -117,8 +117,8 @@ KPreviewWidgetBase * KFileMetaPreview::previewProviderFor( const TQString& mimeT
parentMimeType = parentMimeInfo->parentMimeType();
}
- // check X-KDE-Text property
- TQVariant textProperty = mimeInfo->property( "X-KDE-text" );
+ // check X-TDE-Text property
+ TQVariant textProperty = mimeInfo->property( "X-TDE-text" );
if ( textProperty.isValid() && textProperty.type() == TQVariant::Bool )
{
if ( textProperty.toBool() )
diff --git a/kio/kfile/kopenwith.cpp b/kio/kfile/kopenwith.cpp
index 2a3e7e690..8f498aa8d 100644
--- a/kio/kfile/kopenwith.cpp
+++ b/kio/kfile/kopenwith.cpp
@@ -768,7 +768,7 @@ void KOpenWithDlg::slotOK()
{
// Also make sure the "auto embed" setting for this mimetype is off
KDesktopFile mimeDesktop( locateLocal( "mime", qServiceType + ".desktop" ) );
- mimeDesktop.writeEntry( "X-KDE-AutoEmbed", false );
+ mimeDesktop.writeEntry( "X-TDE-AutoEmbed", false );
mimeDesktop.sync();
}
}
diff --git a/kio/kfile/kpropertiesdialog.cpp b/kio/kfile/kpropertiesdialog.cpp
index 29537bc2b..30d6e0637 100644
--- a/kio/kfile/kpropertiesdialog.cpp
+++ b/kio/kfile/kpropertiesdialog.cpp
@@ -518,8 +518,8 @@ void KPropertiesDialog::insertPages()
TQString query = TQString::fromLatin1(
"('KPropsDlg/Plugin' in ServiceTypes) and "
- "((not exist [X-KDE-Protocol]) or "
- " ([X-KDE-Protocol] == '%1' ) )" ).arg(item->url().protocol());
+ "((not exist [X-TDE-Protocol]) or "
+ " ([X-TDE-Protocol] == '%1' ) )" ).arg(item->url().protocol());
kdDebug( 250 ) << "trader query: " << query << endl;
KTrader::OfferList offers = KTrader::self()->query( mimetype, query );
@@ -2742,8 +2742,8 @@ KBindingPropsPlugin::KBindingPropsPlugin( KPropertiesDialog *_props ) : KPropsDl
if ( !m_sMimeStr.isEmpty() )
mimeEdit->setText( m_sMimeStr );
cbAutoEmbed->setTristate();
- if ( config.hasKey( "X-KDE-AutoEmbed" ) )
- cbAutoEmbed->setChecked( config.readBoolEntry( "X-KDE-AutoEmbed" ) );
+ if ( config.hasKey( "X-TDE-AutoEmbed" ) )
+ cbAutoEmbed->setChecked( config.readBoolEntry( "X-TDE-AutoEmbed" ) );
else
cbAutoEmbed->setNoChange();
@@ -2804,9 +2804,9 @@ void KBindingPropsPlugin::applyChanges()
commentEdit->text(), true, false, true ); // for compat
config.writeEntry( "MimeType", mimeEdit->text() );
if ( cbAutoEmbed->state() == TQButton::NoChange )
- config.deleteEntry( "X-KDE-AutoEmbed", false );
+ config.deleteEntry( "X-TDE-AutoEmbed", false );
else
- config.writeEntry( "X-KDE-AutoEmbed", cbAutoEmbed->isChecked() );
+ config.writeEntry( "X-TDE-AutoEmbed", cbAutoEmbed->isChecked() );
config.sync();
}
@@ -3154,12 +3154,12 @@ KDesktopPropsPlugin::KDesktopPropsPlugin( KPropertiesDialog *_props )
TQString pathStr = config.readPathEntry( "Path" );
m_terminalBool = config.readBoolEntry( "Terminal" );
m_terminalOptionStr = config.readEntry( "TerminalOptions" );
- m_suidBool = config.readBoolEntry( "X-KDE-SubstituteUID" );
- m_suidUserStr = config.readEntry( "X-KDE-Username" );
+ m_suidBool = config.readBoolEntry( "X-TDE-SubstituteUID" );
+ m_suidUserStr = config.readEntry( "X-TDE-Username" );
if( config.hasKey( "StartupNotify" ))
m_startupBool = config.readBoolEntry( "StartupNotify", true );
else
- m_startupBool = config.readBoolEntry( "X-KDE-StartupNotify", true );
+ m_startupBool = config.readBoolEntry( "X-TDE-StartupNotify", true );
m_dcopServiceType = config.readEntry("X-DCOP-ServiceType").lower();
TQStringList mimeTypes = config.readListEntry( "MimeType", ';' );
@@ -3395,8 +3395,8 @@ void KDesktopPropsPlugin::applyChanges()
config.writeEntry("Terminal", m_terminalBool);
config.writeEntry("TerminalOptions", m_terminalOptionStr);
- config.writeEntry("X-KDE-SubstituteUID", m_suidBool);
- config.writeEntry("X-KDE-Username", m_suidUserStr);
+ config.writeEntry("X-TDE-SubstituteUID", m_suidBool);
+ config.writeEntry("X-TDE-Username", m_suidUserStr);
config.writeEntry("StartupNotify", m_startupBool);
config.writeEntry("X-DCOP-ServiceType", m_dcopServiceType);
config.sync();
@@ -3734,8 +3734,8 @@ KExecPropsPlugin::KExecPropsPlugin( KPropertiesDialog *_props )
swallowTitleStr = config.readEntry( "SwallowTitle" );
termBool = config.readBoolEntry( "Terminal" );
termOptionsStr = config.readEntry( "TerminalOptions" );
- suidBool = config.readBoolEntry( "X-KDE-SubstituteUID" );
- suidUserStr = config.readEntry( "X-KDE-Username" );
+ suidBool = config.readBoolEntry( "X-TDE-SubstituteUID" );
+ suidUserStr = config.readEntry( "X-TDE-Username" );
if ( !swallowExecStr.isNull() )
swallowExecEdit->setText( swallowExecStr );
@@ -3865,8 +3865,8 @@ void KExecPropsPlugin::applyChanges()
temp += TQString::fromLatin1("--noclose ");
temp = temp.stripWhiteSpace();
config.writeEntry( "TerminalOptions", temp );
- config.writeEntry( "X-KDE-SubstituteUID", suidCheck->isChecked() );
- config.writeEntry( "X-KDE-Username", suidEdit->text() );
+ config.writeEntry( "X-TDE-SubstituteUID", suidCheck->isChecked() );
+ config.writeEntry( "X-TDE-Username", suidEdit->text() );
}
diff --git a/kio/kfile/kpropertiesdialog.h b/kio/kfile/kpropertiesdialog.h
index 4243bf602..91439f8cc 100644
--- a/kio/kfile/kpropertiesdialog.h
+++ b/kio/kfile/kpropertiesdialog.h
@@ -431,7 +431,7 @@ private:
* servicetype, as well as the mimetypes for which the plugin should be created.
* For instance, ServiceTypes=KPropsDlg/Plugin,text/html,application/x-mymimetype.
*
- * You can also include X-KDE-Protocol=file if you want that plugin
+ * You can also include X-TDE-Protocol=file if you want that plugin
* to be loaded only for local files, for instance.
*/
class KIO_EXPORT KPropsDlgPlugin : public TQObject
diff --git a/kio/kfile/kpropsdlgplugin.desktop b/kio/kfile/kpropsdlgplugin.desktop
index b4ced80e6..f74e3895e 100644
--- a/kio/kfile/kpropsdlgplugin.desktop
+++ b/kio/kfile/kpropsdlgplugin.desktop
@@ -1,6 +1,6 @@
[Desktop Entry]
Type=ServiceType
-X-KDE-ServiceType=KPropsDlg/Plugin
+X-TDE-ServiceType=KPropsDlg/Plugin
Comment=Plugin for the Properties Dialog
Comment[af]=Inprop module vir die Eienskappe Dialoog
Comment[ar]=ملحق لمربع حوار خصائص
@@ -83,5 +83,5 @@ Comment[zh_HK]=屬性對話盒的外掛程式
Comment[zh_TW]=屬性對話盒的外掛程式
Comment[zu]=I-plugin Yengxoxo Yezinkomba zobunini
-[PropertyDef::X-KDE-Protocol]
+[PropertyDef::X-TDE-Protocol]
Type=TQString
diff --git a/kio/kfile/krecentdocument.cpp b/kio/kfile/krecentdocument.cpp
index d691de359..7ad690be4 100644
--- a/kio/kfile/krecentdocument.cpp
+++ b/kio/kfile/krecentdocument.cpp
@@ -108,7 +108,7 @@ void KRecentDocument::add(const KURL& url, const TQString& desktopEntryName)
// see if it points to the same file and application
KSimpleConfig tmp(ddesktop);
tmp.setDesktopGroup();
- if(tmp.readEntry(TQString::fromLatin1("X-KDE-LastOpenedWith"))
+ if(tmp.readEntry(TQString::fromLatin1("X-TDE-LastOpenedWith"))
== desktopEntryName)
{
utime(TQFile::encodeName(ddesktop), NULL);
@@ -140,7 +140,7 @@ void KRecentDocument::add(const KURL& url, const TQString& desktopEntryName)
conf.writeEntry( TQString::fromLatin1("Type"), TQString::fromLatin1("Link") );
conf.writePathEntry( TQString::fromLatin1("URL"), openStr );
// If you change the line below, change the test in the above loop
- conf.writeEntry( TQString::fromLatin1("X-KDE-LastOpenedWith"), desktopEntryName );
+ conf.writeEntry( TQString::fromLatin1("X-TDE-LastOpenedWith"), desktopEntryName );
TQString name = url.fileName();
if (name.isEmpty())
name = openStr;
diff --git a/kio/kfileplugin.desktop b/kio/kfileplugin.desktop
index 87c9194fe..6609551a6 100644
--- a/kio/kfileplugin.desktop
+++ b/kio/kfileplugin.desktop
@@ -1,6 +1,6 @@
[Desktop Entry]
Type=ServiceType
-X-KDE-ServiceType=KFilePlugin
+X-TDE-ServiceType=KFilePlugin
Name=KFile Meta Data Plugin
Name[af]=Klêer Meta Data Inprop module
Name[ar]=ملحق KFile Meta Data
diff --git a/kio/kio/job.cpp b/kio/kio/job.cpp
index 58bb00c58..fc1a9645f 100644
--- a/kio/kio/job.cpp
+++ b/kio/kio/job.cpp
@@ -2115,7 +2115,7 @@ void ListJob::slotFinished()
if ( m_error == KIO::ERR_IS_FILE && m_url.isLocalFile() ) {
KMimeType::Ptr ptr = KMimeType::findByURL( m_url, 0, true, true );
if ( ptr ) {
- TQString proto = ptr->property("X-KDE-LocalProtocol").toString();
+ TQString proto = ptr->property("X-TDE-LocalProtocol").toString();
if ( !proto.isEmpty() && KProtocolInfo::isKnownProtocol(proto) ) {
m_redirectionURL = m_url;
m_redirectionURL.setProtocol( proto );
diff --git a/kio/kio/kfilemetainfo.cpp b/kio/kio/kfilemetainfo.cpp
index dcf735619..4abecfbf3 100644
--- a/kio/kio/kfilemetainfo.cpp
+++ b/kio/kio/kfilemetainfo.cpp
@@ -934,10 +934,10 @@ KFilePlugin* KFileMetaInfoProvider::loadPlugin( const TQString& mimeType, const
// We need PNG fileinfo, and trash: fileinfo, but not "PNG in the trash".
TQString queryMimeType, query;
if ( !mimeType.isEmpty() ) {
- query = "(not exist [X-KDE-Protocol])";
+ query = "(not exist [X-TDE-Protocol])";
queryMimeType = mimeType;
} else {
- query = TQString::fromLatin1( "[X-KDE-Protocol] == '%1'" ).arg(protocol);
+ query = TQString::fromLatin1( "[X-TDE-Protocol] == '%1'" ).arg(protocol);
// querying for a protocol: we have no mimetype, so we need to use KFilePlugin as one
queryMimeType = "KFilePlugin";
// hopefully using KFilePlugin as genericMimeType too isn't a problem
diff --git a/kio/kio/kfilemetainfo.h b/kio/kio/kfilemetainfo.h
index 1552ede9f..b71ab0fa0 100644
--- a/kio/kio/kfilemetainfo.h
+++ b/kio/kio/kfilemetainfo.h
@@ -1369,7 +1369,7 @@ private:
* - @c Type: must be @c "Service"
* - @c Name: the name of the plugin
* - @c ServiceTypes: must contain @c "KFilePlugin"
- * - @c X-KDE-Library: the name of the library containing the KFile plugin
+ * - @c X-TDE-Library: the name of the library containing the KFile plugin
* - @c MimeType: the mimetype(s) which are supported by the plugin
* - @c PreferredGroups: a comma-separated list of the most important groups.
* This list defines the order in which the meta information groups should be
@@ -1385,7 +1385,7 @@ private:
* Type=Service
* Name=Foo Info
* ServiceTypes=KFilePlugin
- * X-KDE-Library=kfile_foo
+ * X-TDE-Library=kfile_foo
* MimeType=application/x-foo
* PreferredGroups=FooInfo
* PreferredItems=Items,Size
diff --git a/kio/kio/kmimetype.h b/kio/kio/kmimetype.h
index 22f9b72ef..b5ffdc9df 100644
--- a/kio/kio/kmimetype.h
+++ b/kio/kio/kmimetype.h
@@ -406,7 +406,7 @@ public:
* return the name of the parent.
*
* For instance a text/x-log is a special kind of text/plain,
- * so the definition of text/x-log can say "X-KDE-IsAlso=text/plain".
+ * so the definition of text/x-log can say "X-TDE-IsAlso=text/plain".
* Or an smb-workgroup is a special kind of inode/directory, etc.
* This mechanism can also be used to rename mimetypes and preserve compat.
*
@@ -570,7 +570,7 @@ public:
/**
* Overload of userDefinedServices but also allows you to pass a list of urls for this file.
* This allows for the menu to be changed depending on the exact files via
- * the X-KDE-GetActionMenu extension.
+ * the X-TDE-GetActionMenu extension.
* @since 3.5
*/
static TQValueList<Service> userDefinedServices( const TQString& path, KConfig& config, bool bLocalFiles, const KURL::List & file_list);
diff --git a/kio/kio/krun.cpp b/kio/kio/krun.cpp
index f09fccfa4..93cbe677a 100644
--- a/kio/kio/krun.cpp
+++ b/kio/kio/krun.cpp
@@ -406,7 +406,7 @@ TQStringList KRun::processDesktopExec(const KService &_service, const KURL::List
// FIXME: the current way of invoking kioexec disables term and su use
// Check if we need "tempexec" (kioexec in fact)
- appHasTempFileOption = tempFiles && _service.property("X-KDE-HasTempFileOption").toBool();
+ appHasTempFileOption = tempFiles && _service.property("X-TDE-HasTempFileOption").toBool();
if( tempFiles && !appHasTempFileOption && _urls.size() ) {
result << "kioexec" << "--tempfiles" << exec;
result += _urls.toStringList();
@@ -616,10 +616,10 @@ bool KRun::checkStartupNotify( const TQString& /*binName*/, const KService* serv
silent = !service->property( "StartupNotify" ).toBool();
wmclass = service->property( "StartupWMClass" ).toString().latin1();
}
- else if( service && service->property( "X-KDE-StartupNotify" ).isValid())
+ else if( service && service->property( "X-TDE-StartupNotify" ).isValid())
{
- silent = !service->property( "X-KDE-StartupNotify" ).toBool();
- wmclass = service->property( "X-KDE-WMClass" ).toString().latin1();
+ silent = !service->property( "X-TDE-StartupNotify" ).toBool();
+ wmclass = service->property( "X-TDE-WMClass" ).toString().latin1();
}
else // non-compliant app
{
@@ -698,7 +698,7 @@ static KURL::List resolveURLs( const KURL::List& _urls, const KService& _service
{
// Check which protocols the application supports.
// This can be a list of actual protocol names, or just KIO for KDE apps.
- TQStringList supportedProtocols = _service.property("X-KDE-Protocols").toStringList();
+ TQStringList supportedProtocols = _service.property("X-TDE-Protocols").toStringList();
KRunMX1 mx1( _service );
TQString exec = _service.exec();
if ( mx1.expandMacrosShellQuote( exec ) && !mx1.hasUrls ) {
diff --git a/kio/kio/krun.h b/kio/kio/krun.h
index 5cf8189c9..e6aa4d027 100644
--- a/kio/kio/krun.h
+++ b/kio/kio/krun.h
@@ -165,7 +165,7 @@ public:
* Set the preferred service for opening this URL, after
* its mimetype will have been found by KRun. IMPORTANT: the service is
* only used if its configuration says it can handle this mimetype.
- * This is used for instance for the X-KDE-LastOpenedWith key, for
+ * This is used for instance for the X-TDE-LastOpenedWith key, for
* the recent documents list.
* @param desktopEntryName the desktopEntryName of the service, e.g. "kate".
*/
@@ -374,7 +374,7 @@ public:
* -# The mime type must inherit application/x-executable or application/x-executable-script.
* To allow a script to run when the above rules are satisfied add the entry
* @code
- * X-KDE-IsAlso=application/x-executable-script
+ * X-TDE-IsAlso=application/x-executable-script
* @endcode
* to the mimetype's desktop file.
* @since 3.3
diff --git a/kio/kio/kservice.cpp b/kio/kio/kservice.cpp
index b5d970291..28ee1b91e 100644
--- a/kio/kio/kservice.cpp
+++ b/kio/kio/kservice.cpp
@@ -199,7 +199,7 @@ KService::init( KDesktopFile *config )
m_strExec = config->readPathEntry( "Exec" );
if (kde4application && !m_strExec.startsWith("/")) {
m_strExec = "TDEHOME=$HOME/.kde XDG_DATA_DIRS=/usr/share TDEDIRS=/usr/ XDG_CONFIG_DIRS=/etc/xdg/ PATH=/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/games:$PATH "+m_strExec;
- } else if (config->readBoolEntry("X-KDE-SubstituteUID")) {
+ } else if (config->readBoolEntry("X-TDE-SubstituteUID")) {
int space = m_strExec.find(" ");
if (space==-1)
m_strExec = KStandardDirs::findExe(m_strExec);
@@ -241,10 +241,10 @@ KService::init( KDesktopFile *config )
entryMap.remove("Keywords");
d->categories = config->readListEntry("Categories", ';');
entryMap.remove("Categories");
- m_strLibrary = config->readEntry( "X-KDE-Library" );
- entryMap.remove("X-KDE-Library");
- m_strInit = config->readEntry("X-KDE-Init" );
- entryMap.remove("X-KDE-Init");
+ m_strLibrary = config->readEntry( "X-TDE-Library" );
+ entryMap.remove("X-TDE-Library");
+ m_strInit = config->readEntry("X-TDE-Init" );
+ entryMap.remove("X-TDE-Init");
m_lstServiceTypes = config->readListEntry( "ServiceTypes" );
entryMap.remove("ServiceTypes");
@@ -275,8 +275,8 @@ KService::init( KDesktopFile *config )
m_bAllowAsDefault = config->readBoolEntry( "AllowDefault", true );
entryMap.remove("AllowDefault");
- m_initialPreference = config->readNumEntry( "X-KDE-InitialPreference", 1 );
- entryMap.remove("X-KDE-InitialPreference");
+ m_initialPreference = config->readNumEntry( "X-TDE-InitialPreference", 1 );
+ entryMap.remove("X-TDE-InitialPreference");
if ( m_initialPreference == 1 )
m_initialPreference = config->readNumEntry( "InitialPreference", 1 );
entryMap.remove("InitialPreference");
@@ -703,14 +703,14 @@ KService::List KService::allInitServices()
}
bool KService::substituteUid() const {
- TQVariant v = property("X-KDE-SubstituteUID", TQVariant::Bool);
+ TQVariant v = property("X-TDE-SubstituteUID", TQVariant::Bool);
return v.isValid() && v.toBool();
}
TQString KService::username() const {
// See also KDesktopFile::tryExec()
TQString user;
- TQVariant v = property("X-KDE-Username", TQVariant::String);
+ TQVariant v = property("X-TDE-Username", TQVariant::String);
user = v.isValid() ? v.toString() : TQString::null;
if (user.isEmpty())
user = ::getenv("ADMIN_ACCOUNT");
@@ -772,7 +772,7 @@ bool KService::SuSEunimportant() const {
}
TQString KService::parentApp() const {
- TQMap<TQString,TQVariant>::ConstIterator it = m_mapProps.find( "X-KDE-ParentApp" );
+ TQMap<TQString,TQVariant>::ConstIterator it = m_mapProps.find( "X-TDE-ParentApp" );
if ( (it == m_mapProps.end()) || (!it.data().isValid()))
{
return TQString::null;
diff --git a/kio/kio/kservicefactory.h b/kio/kio/kservicefactory.h
index 1a828364e..b419f5947 100644
--- a/kio/kio/kservicefactory.h
+++ b/kio/kio/kservicefactory.h
@@ -82,7 +82,7 @@ public:
KService::List allServices();
/**
- * @return all services which have a "X-KDE-Init" line.
+ * @return all services which have a "X-TDE-Init" line.
*/
KService::List allInitServices();
diff --git a/kio/kio/kservicegroup.cpp b/kio/kio/kservicegroup.cpp
index 6758ca1c0..af69e1765 100644
--- a/kio/kio/kservicegroup.cpp
+++ b/kio/kio/kservicegroup.cpp
@@ -93,8 +93,8 @@ KServiceGroup::KServiceGroup( const TQString &configFile, const TQString & _relp
d->m_bNoDisplay = true;
}
- m_strBaseGroupName = config.readEntry( "X-KDE-BaseGroup" );
- d->suppressGenericNames = config.readListEntry( "X-KDE-SuppressGenericNames" );
+ m_strBaseGroupName = config.readEntry( "X-TDE-BaseGroup" );
+ d->suppressGenericNames = config.readListEntry( "X-TDE-SuppressGenericNames" );
d->sortOrder = config.readListEntry("SortOrder");
// Fill in defaults.
diff --git a/kio/kio/kservicegroup.h b/kio/kio/kservicegroup.h
index 69242e6ed..afc043adf 100644
--- a/kio/kio/kservicegroup.h
+++ b/kio/kio/kservicegroup.h
@@ -257,7 +257,7 @@ public:
* and "System/Screensavers/" is the screensavers base group ("screensavers").
* This allows moving the groups without breaking those apps.
*
- * The base group is defined by the X-KDE-BaseGroup key
+ * The base group is defined by the X-TDE-BaseGroup key
* in the .directory file.
* @return the base group name, or null if no base group
*/
@@ -291,7 +291,7 @@ public:
static Ptr group(const TQString &relPath);
/**
- * Returns the group of services that have X-KDE-ParentApp equal
+ * Returns the group of services that have X-TDE-ParentApp equal
* to @p parent (siblings).
* @param parent the name of the service's parent
* @return the services group
diff --git a/kio/kio/kservicetype.cpp b/kio/kio/kservicetype.cpp
index f11cb99b9..994495921 100644
--- a/kio/kio/kservicetype.cpp
+++ b/kio/kio/kservicetype.cpp
@@ -63,7 +63,7 @@ KServiceType::init( KDesktopFile *config)
// Or is it a servicetype ?
if ( m_strName.isEmpty() )
{
- m_strName = config->readEntry( "X-KDE-ServiceType" );
+ m_strName = config->readEntry( "X-TDE-ServiceType" );
}
m_strComment = config->readComment();
@@ -72,10 +72,10 @@ KServiceType::init( KDesktopFile *config)
// We store this as property to preserve BC, we can't change that
// because KSycoca needs to remain BC between KDE 2.x and KDE 3.x
- TQString sDerived = config->readEntry( "X-KDE-Derived" );
+ TQString sDerived = config->readEntry( "X-TDE-Derived" );
m_bDerived = !sDerived.isEmpty();
if ( m_bDerived )
- m_mapProps.insert( "X-KDE-Derived", sDerived );
+ m_mapProps.insert( "X-TDE-Derived", sDerived );
TQStringList tmpList = config->groupList();
TQStringList::Iterator gIt = tmpList.begin();
@@ -129,7 +129,7 @@ KServiceType::load( TQDataStream& _str )
_str >> m_strName >> m_strIcon >> m_strComment >> m_mapProps >> m_mapPropDefs
>> b;
m_bValid = b;
- m_bDerived = m_mapProps.contains("X-KDE-Derived");
+ m_bDerived = m_mapProps.contains("X-TDE-Derived");
}
void
@@ -150,7 +150,7 @@ KServiceType::~KServiceType()
TQString KServiceType::parentServiceType() const
{
- TQVariant v = property("X-KDE-Derived");
+ TQVariant v = property("X-TDE-Derived");
return v.toString();
}
diff --git a/kio/kio/ktrader.h b/kio/kio/ktrader.h
index c1547a35c..8abf09870 100644
--- a/kio/kio/ktrader.h
+++ b/kio/kio/ktrader.h
@@ -68,13 +68,13 @@
* Please note that when including property names containing arithmetic operators like - or +, then you have
* to put brackets around the property name, in order to correctly separate arithmetic operations from
* the name. So for example a constraint expression like
- * X-KDE-Blah < 4
+ * X-TDE-Blah < 4
* needs to be written as
- * [X-KDE-Blah] < 4
+ * [X-TDE-Blah] < 4
* otherwise it could also be interpreted as
* Substract the numeric value of the property "KDE" and "Blah" from the property "X" and make sure it
* is less than 4.
- * Instead of the other meaning, make sure that the numeric value of "X-KDE-Blah" is less than 4.
+ * Instead of the other meaning, make sure that the numeric value of "X-TDE-Blah" is less than 4.
*
* See also the formal syntax defined in @ref tradersyntax .
*
@@ -202,7 +202,7 @@ protected:
* list of the service types it supports. Note that only properties can
* be written as-is which start with an alphabetical character and contain
* only alphanumerical characters. Other properties have to be enclosed in
- * brackets, e.g. <tt>[X-KDE-Init]</tt>. Properties must not contain any
+ * brackets, e.g. <tt>[X-TDE-Init]</tt>. Properties must not contain any
* special characters other than <tt>-</tt>.
*
* Special property names:
@@ -214,7 +214,7 @@ protected:
* here for completeness, better not use it (things can be moved
* around).
* - <b>Library</b> is the property whose value is set by
- * <tt>X-KDE-Library</tt> in the .desktop file. This renaming
+ * <tt>X-TDE-Library</tt> in the .desktop file. This renaming
* happened to conform to the desktop file standard, but the
* property name didn't change.
*
diff --git a/kio/kio/previewjob.cpp b/kio/kio/previewjob.cpp
index 3b428c847..2249a1bfa 100644
--- a/kio/kio/previewjob.cpp
+++ b/kio/kio/previewjob.cpp
@@ -208,9 +208,9 @@ void PreviewJob::startPreview()
if (plugin == mimeMap.end())
{
- // check X-KDE-Text property
+ // check X-TDE-Text property
KMimeType::Ptr mimeInfo = KMimeType::mimeType(it.current()->mimetype());
- TQVariant textProperty = mimeInfo->property("X-KDE-text");
+ TQVariant textProperty = mimeInfo->property("X-TDE-text");
if (textProperty.isValid() && textProperty.type() == TQVariant::Bool)
{
if (textProperty.toBool())
diff --git a/kio/kio/thumbcreator.h b/kio/kio/thumbcreator.h
index 17a7fac30..3ad6ca8aa 100644
--- a/kio/kio/thumbcreator.h
+++ b/kio/kio/thumbcreator.h
@@ -65,7 +65,7 @@ class TQImage;
* ServiceTypes=ThumbCreator
* MimeTypes=application/x-somemimetype
* CacheThumbnail=true
- * X-KDE-Library=yourthumbcreator
+ * X-TDE-Library=yourthumbcreator
* \endcode
*
* You can supply a comma-separated list of mimetypes to the MimeTypes entry,
diff --git a/kio/kpasswdserver.desktop b/kio/kpasswdserver.desktop
index d41a96506..d0c1c0eba 100644
--- a/kio/kpasswdserver.desktop
+++ b/kio/kpasswdserver.desktop
@@ -150,8 +150,8 @@ Comment[zh_CN]=密码缓存支持
Comment[zh_HK]=密碼暫存支援
Comment[zh_TW]=密碼暫存(cache)支援
ServiceTypes=KDEDModule
-X-KDE-ModuleType=Library
-X-KDE-Library=kpasswdserver
-X-KDE-FactoryName=kpasswdserver
-X-KDE-Kded-autoload=false
-X-KDE-Kded-load-on-demand=true
+X-TDE-ModuleType=Library
+X-TDE-Library=kpasswdserver
+X-TDE-FactoryName=kpasswdserver
+X-TDE-Kded-autoload=false
+X-TDE-Kded-load-on-demand=true
diff --git a/kio/kscan.desktop b/kio/kscan.desktop
index 5d6d94b56..8d3a026fb 100644
--- a/kio/kscan.desktop
+++ b/kio/kscan.desktop
@@ -1,6 +1,6 @@
[Desktop Entry]
Type=ServiceType
-X-KDE-ServiceType=KScan/KScanDialog
+X-TDE-ServiceType=KScan/KScanDialog
Name=KScan
Name[bn]=কে-স্ক্যান
Name[cy]=KSgan
diff --git a/kio/kurifilterplugin.desktop b/kio/kurifilterplugin.desktop
index 85e4f2b84..5882b35ca 100644
--- a/kio/kurifilterplugin.desktop
+++ b/kio/kurifilterplugin.desktop
@@ -1,6 +1,6 @@
[Desktop Entry]
Type=ServiceType
-X-KDE-ServiceType=KURIFilter/Plugin
+X-TDE-ServiceType=KURIFilter/Plugin
Name=Enhanced Browsing Plugin
Name[af]=Verbeterde Blaaiïng Inprop module
Name[ar]=ملحقات التصفح المحسن
diff --git a/kio/misc/kio_uiserver.desktop b/kio/misc/kio_uiserver.desktop
index c47d0a394..fd37cd2bd 100644
--- a/kio/misc/kio_uiserver.desktop
+++ b/kio/misc/kio_uiserver.desktop
@@ -97,4 +97,4 @@ Comment[zu]=Umlekeleli we-UI Yolwazi Lwenqubo lwe-TDE
ServiceTypes=
# It is a server
X-DCOP-ServiceType=Unique
-X-KDE-StartupNotify=false
+X-TDE-StartupNotify=false
diff --git a/kio/misc/kpac/proxyscout.desktop b/kio/misc/kpac/proxyscout.desktop
index 2f1b28f84..02e402b50 100644
--- a/kio/misc/kpac/proxyscout.desktop
+++ b/kio/misc/kpac/proxyscout.desktop
@@ -124,8 +124,8 @@ Comment[zh_CN]=自动代理配置
Comment[zh_HK]=自動代理伺服器組態
Comment[zh_TW]=自動代理組態
ServiceTypes=KDEDModule
-X-KDE-ModuleType=Library
-X-KDE-Library=proxyscout
-X-KDE-FactoryName=proxyscout
-X-KDE-Kded-autoload=false
-X-KDE-Kded-load-on-demand=true
+X-TDE-ModuleType=Library
+X-TDE-Library=proxyscout
+X-TDE-FactoryName=proxyscout
+X-TDE-Kded-autoload=false
+X-TDE-Kded-load-on-demand=true
diff --git a/kio/misc/kssld/kssld.desktop b/kio/misc/kssld/kssld.desktop
index bbabf17a1..600c0609c 100644
--- a/kio/misc/kssld/kssld.desktop
+++ b/kio/misc/kssld/kssld.desktop
@@ -1,11 +1,11 @@
[Desktop Entry]
Type=Service
ServiceTypes=KDEDModule
-X-KDE-ModuleType=Library
-X-KDE-Library=kssld
-X-KDE-FactoryName=kssld
-X-KDE-Kded-autoload=false
-X-KDE-Kded-load-on-demand=true
+X-TDE-ModuleType=Library
+X-TDE-Library=kssld
+X-TDE-FactoryName=kssld
+X-TDE-Kded-autoload=false
+X-TDE-Kded-load-on-demand=true
Name=KSSL Daemon Module
Name[af]=Kssl Bediener Module
Name[ar]=وحدة مراقب KSSL
diff --git a/kio/misc/kwalletd/kwalletd.desktop b/kio/misc/kwalletd/kwalletd.desktop
index b33851ceb..09aaad714 100644
--- a/kio/misc/kwalletd/kwalletd.desktop
+++ b/kio/misc/kwalletd/kwalletd.desktop
@@ -1,11 +1,11 @@
[Desktop Entry]
Type=Service
ServiceTypes=KDEDModule
-X-KDE-ModuleType=Library
-X-KDE-Library=kwalletd
-X-KDE-FactoryName=kwalletd
-X-KDE-Kded-autoload=false
-X-KDE-Kded-load-on-demand=true
+X-TDE-ModuleType=Library
+X-TDE-Library=kwalletd
+X-TDE-FactoryName=kwalletd
+X-TDE-Kded-autoload=false
+X-TDE-Kded-load-on-demand=true
Name=KWallet Daemon Module
Name[af]=KBeursie Bediener Module
Name[ar]=مراقب وحدة KWallet
diff --git a/kio/renamedlgplugin.desktop b/kio/renamedlgplugin.desktop
index f951a48e2..d6a9f8f1f 100644
--- a/kio/renamedlgplugin.desktop
+++ b/kio/renamedlgplugin.desktop
@@ -1,6 +1,6 @@
[Desktop Entry]
Type=ServiceType
-X-KDE-ServiceType=RenameDlg/Plugin
+X-TDE-ServiceType=RenameDlg/Plugin
Comment=Plugin for the Rename Dialog
Comment[af]=Inplak vir die Herbenaam Dialoog
Comment[ar]=ملحق لمربع حوار إعادة التسمية
diff --git a/kio/tests/dummymeta.desktop b/kio/tests/dummymeta.desktop
index 5f7373dc9..6d2748c82 100644
--- a/kio/tests/dummymeta.desktop
+++ b/kio/tests/dummymeta.desktop
@@ -49,6 +49,6 @@ Name[zh_CN]=哑元
Name[zh_HK]=空的資料定義
Name[zh_TW]=空的資料定義
ServiceTypes=KFilePlugin
-X-KDE-Library=dummymeta
+X-TDE-Library=dummymeta
MimeType=text/plain
PreferredItems=Author,Title,Date
diff --git a/kio/tests/kruntest.cpp b/kio/tests/kruntest.cpp
index 0febcbc26..673948374 100644
--- a/kio/tests/kruntest.cpp
+++ b/kio/tests/kruntest.cpp
@@ -140,7 +140,7 @@ int main(int argc, char **argv)
static const char
*execs[] = { "Exec=date -u", "Exec=echo $$PWD" },
*terms[] = { "Terminal=false", "Terminal=true\nTerminalOptions=-T \"%f - %c\"" },
- *sus[] = { "X-KDE-SubstituteUID=false", "X-KDE-SubstituteUID=true\nX-KDE-Username=sprallo" },
+ *sus[] = { "X-TDE-SubstituteUID=false", "X-TDE-SubstituteUID=true\nX-TDE-Username=sprallo" },
*rslts[] = {
"'date' '-u'", // 0
"'/bin/sh' '-c' 'echo $PWD '", // 1
diff --git a/kio/kio/kmimetype.cpp b/kio/kio/kmimetype.cpp
index 5d650b4b2..461207d9a 100644
--- a/kio/kio/kmimetype.cpp
+++ b/kio/kio/kmimetype.cpp
@@ -334,7 +334,7 @@ KMimeType::Format KMimeType::findFormatByFileContent( const TQString &fileName )
KMimeType::Ptr mime = findByPath(fileName);
result.text = mime->name().startsWith("text/");
- TQVariant v = mime->property("X-KDE-text");
+ TQVariant v = mime->property("X-TDE-text");
if (v.isValid())
result.text = v.toBool();
@@ -381,16 +381,16 @@ void KMimeType::init( KDesktopFile * config )
config->setDesktopGroup();
m_lstPatterns = config->readListEntry( "Patterns", ';' );
- // Read the X-KDE-AutoEmbed setting and store it in the properties map
- TQString XKDEAutoEmbed = TQString::fromLatin1("X-KDE-AutoEmbed");
+ // Read the X-TDE-AutoEmbed setting and store it in the properties map
+ TQString XKDEAutoEmbed = TQString::fromLatin1("X-TDE-AutoEmbed");
if ( config->hasKey( XKDEAutoEmbed ) )
m_mapProps.insert( XKDEAutoEmbed, TQVariant( config->readBoolEntry( XKDEAutoEmbed ), 0 ) );
- TQString XKDEText = TQString::fromLatin1("X-KDE-text");
+ TQString XKDEText = TQString::fromLatin1("X-TDE-text");
if ( config->hasKey( XKDEText ) )
m_mapProps.insert( XKDEText, config->readBoolEntry( XKDEText ) );
- TQString XKDEIsAlso = TQString::fromLatin1("X-KDE-IsAlso");
+ TQString XKDEIsAlso = TQString::fromLatin1("X-TDE-IsAlso");
if ( config->hasKey( XKDEIsAlso ) ) {
TQString inherits = config->readEntry( XKDEIsAlso );
if ( inherits != name() )
@@ -399,7 +399,7 @@ void KMimeType::init( KDesktopFile * config )
kdWarning(7009) << "Error: " << inherits << " inherits from itself!!!!" << endl;
}
- TQString XKDEPatternsAccuracy = TQString::fromLatin1("X-KDE-PatternsAccuracy");
+ TQString XKDEPatternsAccuracy = TQString::fromLatin1("X-TDE-PatternsAccuracy");
if ( config->hasKey( XKDEPatternsAccuracy ) )
m_mapProps.insert( XKDEPatternsAccuracy, config->readEntry( XKDEPatternsAccuracy ) );
@@ -552,7 +552,7 @@ TQString KMimeType::favIconForURL( const KURL& url )
TQString KMimeType::parentMimeType() const
{
- TQVariant v = property("X-KDE-IsAlso");
+ TQVariant v = property("X-TDE-IsAlso");
return v.toString();
}
@@ -575,7 +575,7 @@ bool KMimeType::is( const TQString& mimeTypeName ) const
}
int KMimeType::patternsAccuracy() const {
- TQVariant v = property("X-KDE-PatternsAccuracy");
+ TQVariant v = property("X-TDE-PatternsAccuracy");
if (!v.isValid()) return 100;
else
return v.toInt();
@@ -880,10 +880,10 @@ pid_t KDEDesktopMimeType::runLink( const KURL& _url, const KSimpleConfig &cfg )
KURL url ( u );
KRun* run = new KRun(url);
// X-KDE-LastOpenedWith holds the service desktop entry name that
// was should be preferred for opening this URL if possible.
// This is used by the Recent Documents menu for instance.
- TQString lastOpenedWidth = cfg.readEntry( "X-KDE-LastOpenedWith" );
+ TQString lastOpenedWidth = cfg.readEntry( "X-TDE-LastOpenedWith" );
if ( !lastOpenedWidth.isEmpty() )
run->setPreferredService( lastOpenedWidth );
@@ -979,7 +979,7 @@ TQValueList<KDEDesktopMimeType::Service> KDEDesktopMimeType::userDefinedServices
cfg.setDesktopGroup();
- if ( !cfg.hasKey( "Actions" ) && !cfg.hasKey( "X-KDE-GetActionMenu") )
+ if ( !cfg.hasKey( "Actions" ) && !cfg.hasKey( "X-TDE-GetActionMenu") )
return result;
if ( cfg.hasKey( "TryExec" ) )
@@ -993,8 +993,8 @@ TQValueList<KDEDesktopMimeType::Service> KDEDesktopMimeType::userDefinedServices
TQStringList keys;
- if( cfg.hasKey( "X-KDE-GetActionMenu" )) {
- TQString dcopcall = cfg.readEntry( "X-KDE-GetActionMenu" );
+ if( cfg.hasKey( "X-TDE-GetActionMenu" )) {
+ TQString dcopcall = cfg.readEntry( "X-TDE-GetActionMenu" );
const TQCString app = TQString(dcopcall.section(' ', 0,0)).utf8();
TQByteArray dataToSend;
@@ -1005,7 +1005,7 @@ TQValueList<KDEDesktopMimeType::Service> KDEDesktopMimeType::userDefinedServices
TQCString object = TQString(dcopcall.section(' ', 1,-2)).utf8();
TQString function = dcopcall.section(' ', -1);
if(!function.endsWith("(KURL::List)")) {
- kdWarning() << "Desktop file " << path << " contains an invalid X-KDE-ShowIfDcopCall - the function must take the exact parameter (KURL::List) and must be specified." << endl;
+ kdWarning() << "Desktop file " << path << " contains an invalid X-TDE-ShowIfDcopCall - the function must take the exact parameter (KURL::List) and must be specified." << endl;
} else {
if(kapp->dcopClient()->call( app, object,
function.utf8(),
@@ -880,10 +880,10 @@ pid_t KDEDesktopMimeType::runLink( const KURL& _url, const KSimpleConfig &cfg )
KURL url ( u );
KRun* run = new KRun(url);
- // X-KDE-LastOpenedWith holds the service desktop entry name that
+ // X-TDE-LastOpenedWith holds the service desktop entry name that
// was should be preferred for opening this URL if possible.
// This is used by the Recent Documents menu for instance.